==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/tb.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

settype($story,"string");
settype($title,"string");
settype($blog_name,"string");
settype($url,"string");
settype($excerpt,"string");
settype($act,"string");
settype($x,"string");

/* get trackback ping */
if ($act == "tb") {

   if (!($CONF['trackback'])) tb_response(true,"TrackBack is not activated!");

   if (KWL_ValidRid($_SERVER['PATH_INFO'])) {
     $story = preg_replace('!^/!','',$_SERVER['PATH_INFO']);
     if (!SqlCount("T_Stories","Rid",$story)) tb_response(true, "Story not found");
   } else tb_response(true, "Invalid TrackBack Ping");

   if (!$title || !$blog_name || !$url || !$excerpt) tb_response(true, "Invalid TrackBack Ping");
/*
   $title = strtr(stripslashes($title),"\t\n"," \r");
   $excerpt = strtr(stripslashes($excerpt),"\t\n"," \r");
   $blog_name = strtr(stripslashes($blog_name),"\t\n"," \r");
   $url = strtr(stripslashes($url),"\t\n"," \r");
*/
   $sql = "INSERT INTO T_Trackback VALUES ('', '$story', '$title', '$blog_name', '$url', '$excerpt', now())";
   if (SqlQuery($sql)) {
      new email ($CONF['SiteName']." - "._NEW_TRACKBACK,
                 _NEW_TRACKBACK_TXT."\n\n".
                 "$CONF[G_URL]/tb.php?story=$story&x=1#". SqlInsertId(),
                 $CONF['SiteName'], "nobody@KorWeblog.Agent",
                 $CONF['EmailAddress']);
      tb_response();
   }

/* delete trackback entry */   
} elseif ($CONF['admin_login'] && $act == "del" && !empty($_GET['tid']) && !empty($_GET['story'])) {
   SqlQuery("DELETE FROM T_Trackback WHERE tid = '{$_GET['tid']}'");
   KWL_Redirect("tb.php?story={$_GET['story']}&x=$x");

/* show trackback entrys */
} else {

   $title = $VAR['Heading'] = $head = _TRACKBACK;
      $VAR['Content'] = "<b>". _TRACKBACK_URL .":</b> ".
         ($CONF['trackback'] ? "{$CONF['G_URL']}/tb.php/$story?act=tb" : _TRACKBACK_NOT_ACT).
         "<br />Encoding: ". strtoupper($rdf_lang);

   if ($x == 1) {
      
      include("include/header.inc.php");
      $m_story = SqlResult("SELECT Heading FROM T_Stories WHERE Rid = '$story'");
      if (empty($m_story)) KWL_ShowError(_NOSTORY1);
      
      $VAR['Content'] .= "<p />" . sprintf(_TRACKBACK_STORY,
            "<b>\"<a href=\"{$CONF['G_URL']}/stories.php?story=$story\">$m_story</a>\"</b>");
   } else {
      
      include("include/popup_head.php");
      $VAR['Content'] .= "<p />\n<b>". _SEND_PING_TXT .":</b> ".
         ($CONF['trackping'] ? "<a href=\"{$CONF['G_URL']}/sendping.php?story=$story\">". _SEND_PING ."</a>\n" : _SEND_PING_NOT_ACT);
      
   }
   KWL_DrawMain($VAR);

   if ($CONF['trackback']) {
      $result = SqlQuery("SELECT * FROM T_Trackback WHERE Rid = '$story' ORDER BY time DESC");
      if (mysql_num_rows($result)) {
         unset($VAR);
         while ($A = mysql_fetch_array($result)) {
            $VAR['Heading'] = "<a name=\"{$A['tid']}\"></a><a class=\"tb_link\" href=\"{$A['url']}\" target=\"_blank\">{$A['title']}</a>";
            $VAR['Content'] = "Submitted by <a class=\"tb_link\" href=\"{$A['url']}\" target=\"_blank\">{$A['blog_name']}</a> - (".
               KWL_DateFormat($A['time']) .")<br /><br />\n";
            
            if ($CONF['tbmsg_length']) {
               $ass = KWL_genSummary($A['excerpt'],$CONF['tbmsg_length']);
               if ($A['excerpt'] != $ass) $ass .= "...";
               $A['excerpt'] =& $ass;
            } 

            $VAR['Content'] .= KWL_ParseContent($A['excerpt'],3);
            if ($CONF['admin_login']) {
               $VAR['Content'] .= "<p align=\"right\">[ <a href=\"tb.php?story=$story&amp;tid={$A['tid']}&amp;act=del&amp;x=$x\">Delete</a> ]";
            }
            KWL_DrawMain($VAR);
         }
      }
   }
 
  if ($x == 1) include("include/footer.inc.php");
  else echo "\n</body>\n</html>\n";
   
}

function tb_response($error=false,$error_message='') {
   if ($error) {
      header("Content-type: text/xml");
      echo '<?xml version="1.0" encoding="iso-8859-1"?'.">\n".
           "<response>\n".
           "<error>1</error>\n".
           "<message>$error_message</message>\n".
           "</response>";
   } else {
      header("Content-type: text/xml");
      echo '<?xml version="1.0" encoding="iso-8859-1"?'.">\n".
           "<response>\n".
           "<error>0</error>\n".
           "</response>";
   }
   exit;
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/tb.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

settype($story,"string");
settype($title,"string");
settype($blog_name,"string");
settype($url,"string");
settype($excerpt,"string");
settype($act,"string");
settype($x,"string");

/* get trackback ping */
if ($act == "tb") {

   if (!($CONF['trackback'])) tb_response(true,"TrackBack is not activated!");

   if (KWL_ValidRid($_SERVER['PATH_INFO'])) {
     $story = preg_replace('!^/!','',$_SERVER['PATH_INFO']);
     if (!SqlCount("T_Stories","Rid",$story)) tb_response(true, "Story not found");
   } else tb_response(true, "Invalid TrackBack Ping");

   if (!$title || !$blog_name || !$url || !$excerpt) tb_response(true, "Invalid TrackBack Ping");
/*
   $title = strtr(stripslashes($title),"\t\n"," \r");
   $excerpt = strtr(stripslashes($excerpt),"\t\n"," \r");
   $blog_name = strtr(stripslashes($blog_name),"\t\n"," \r");
   $url = strtr(stripslashes($url),"\t\n"," \r");
*/
   $sql = "INSERT INTO T_Trackback VALUES ('', '$story', '$title', '$blog_name', '$url', '$excerpt', now())";
   if (SqlQuery($sql)) {
      new email ($CONF['SiteName']." - "._NEW_TRACKBACK,
                 _NEW_TRACKBACK_TXT."\n\n".
                 "$CONF[G_URL]/tb.php?story=$story&x=1#". SqlInsertId(),
                 $CONF['SiteName'], "nobody@KorWeblog.Agent",
                 $CONF['EmailAddress']);
      tb_response();
   }

/* delete trackback entry */   
} elseif ($CONF['admin_login'] && $act == "del" && !empty($_GET['tid']) && !empty($_GET['story'])) {
   SqlQuery("DELETE FROM T_Trackback WHERE tid = '{$_GET['tid']}'");
   KWL_Redirect("tb.php?story={$_GET['story']}&x=$x");

/* show trackback entrys */
} else {

   $title = $VAR['Heading'] = $head = _TRACKBACK;
      $VAR['Content'] = "<b>". _TRACKBACK_URL .":</b> ".
         ($CONF['trackback'] ? "{$CONF['G_URL']}/tb.php/$story?act=tb" : _TRACKBACK_NOT_ACT).
         "<br />Encoding: ". strtoupper($rdf_lang);

   if ($x == 1) {
      
      include("include/header.inc.php");
      $m_story = SqlResult("SELECT Heading FROM T_Stories WHERE Rid = '$story'");
      if (empty($m_story)) KWL_ShowError(_NOSTORY1);
      
      $VAR['Content'] .= "<p />" . sprintf(_TRACKBACK_STORY,
            "<b>\"<a href=\"{$CONF['G_URL']}/stories.php?story=$story\">$m_story</a>\"</b>");
   } else {
      
      include("include/popup_head.php");
      $VAR['Content'] .= "<p />\n<b>". _SEND_PING_TXT .":</b> ".
         ($CONF['trackping'] ? "<a href=\"{$CONF['G_URL']}/sendping.php?story=$story\">". _SEND_PING ."</a>\n" : _SEND_PING_NOT_ACT);
      
   }
   KWL_DrawMain($VAR);

   if ($CONF['trackback']) {
      $result = SqlQuery("SELECT * FROM T_Trackback WHERE Rid = '$story' ORDER BY time DESC");
      if (mysql_num_rows($result)) {
         unset($VAR);
         while ($A = mysql_fetch_array($result)) {
            $VAR['Heading'] = "<a name=\"{$A['tid']}\"></a><a class=\"tb_link\" href=\"{$A['url']}\" target=\"new\">{$A['title']}</a>";
            $VAR['Content'] = "Submitted by <a class=\"tb_link\" href=\"{$A['url']}\" target=\"new\">{$A['blog_name']}</a> - (".
               KWL_DateFormat($A['time']) .")<br /><br />\n";
            
            if ($CONF['tbmsg_length']) {
               $ass = KWL_genSummary($A['excerpt'],$CONF['tbmsg_length']);
               if ($A['excerpt'] != $ass) $ass .= "...";
               $A['excerpt'] =& $ass;
            } 

            $VAR['Content'] .= KWL_ParseContent($A['excerpt'],$CONF['excerpt_parse']);
            if ($CONF['admin_login']) {
               $VAR['Content'] .= "<p align=\"right\">[ <a href=\"tb.php?story=$story&amp;tid={$A['tid']}&amp;act=del&amp;x=$x\">Delete</a> ]";
            }
            KWL_DrawMain($VAR);
         }
      }
   }
 
  if ($x == 1) include("include/footer.inc.php");
  else echo "\n</body>\n</html>\n";
   
}

function tb_response($error=false,$error_message='') {
   if ($error) {
      header("Content-type: text/xml");
      echo '<?xml version="1.0" encoding="iso-8859-1"?'.">\n".
           "<response>\n".
           "<error>1</error>\n".
           "<message>$error_message</message>\n".
           "</response>";
   } else {
      header("Content-type: text/xml");
      echo '<?xml version="1.0" encoding="iso-8859-1"?'.">\n".
           "<response>\n".
           "<error>0</error>\n".
           "</response>";
   }
   exit;
}
?>
